Module: FunWith
- Defined in:
- lib/fun_with/testing/assertions/basics.rb,
lib/fun_with/testing/test_case.rb,
lib/fun_with/testing/verbosity_methods.rb,
lib/fun_with/testing/assertions_test_case.rb,
lib/fun_with/testing/test_case_extensions.rb,
lib/fun_with/testing/assertions_test_mocker.rb
Overview
A namespace module that acts as an umbrella for a collection of gems I'm maintaining. (rdoc)
I seem to be trying to write an entire ecosystem single-handed. It's not going well.
Defined Under Namespace
Modules: Testing