Module: FunWith::Testing
- Defined in:
- lib/fun_with/testing/assertions/basics.rb,
lib/fun_with/testing/test_case.rb,
lib/fun_with/testing/verbosity_methods.rb,
lib/fun_with/testing/assertions_test_case.rb,
lib/fun_with/testing/test_case_extensions.rb,
lib/fun_with/testing/assertions_test_mocker.rb
Overview
A gem that adds a collection of custom assertions to a test suite.
Also includes some infrastructure for testing the assertions themselves.
Other FunWith- gems will contain extensions with their own custom assertions.
For example, FunWith::Files adds in things like assert_directory(), etc.
Defined Under Namespace
Modules: AssertionTestMocker, Assertions, TestCaseExtensions, VerbosityMethods Classes: AssertionsTestCase, TestCase