Module: FunWith::Testing::AssertionTestMocker
- Defined in:
- lib/fun_with/testing/assertions_test_mocker.rb
Instance Method Summary collapse
-
#safe_assert_block(*args, &block) ⇒ Object
Any subclass of Test::Unit::TestCase seems to automatically hook into the test suite.
Instance Method Details
#safe_assert_block(*args, &block) ⇒ Object
Any subclass of Test::Unit::TestCase seems to automatically hook into the test suite. Therefore, calling a test to see if it returns false makes the suite fail. Including to this class instead prevents that.
I may need to more closely mimic Test::Unit::TestCase in order to test messages properly.
10 11 12 |
# File 'lib/fun_with/testing/assertions_test_mocker.rb', line 10 def safe_assert_block( *args, &block ) yield end |